@@ -230,7 +230,7 @@ class Textile(object):
         self.unreferencedNotes = OrderedDict()
         self.notelist_cache = OrderedDict()
 
-        if text == '':
+        if text.strip() == '':
             return text
 
         if self.restricted:
@@ -309,8 +309,13 @@ class Textile(object):
 
             m = re.search(r"^(?P<tl>[#*;:]+)(?P<st>_|\d+)?(?P<atts>{0})[ .]"
                     "(?P<content>.*)$".format(cls_re_s), line, re.S)
-            tl, start, atts, content = m.groups()
-            content = content.strip()
+            if m:
+                tl, start, atts, content = m.groups()
+                content = content.strip()
+            else:
+                result.append(line)
+                continue
+
             nl = ''
             ltype = list_type(tl)
             tl_tags = {';': 'dt', ':': 'dd'}
@@ -365,7 +370,7 @@ class Textile(object):
             if tl not in ls:
                 ls[tl] = 1
                 itemtag = ("\n{0}\t<{1}>{2}".format(tabs, litem, content) if
-                           showitem else '')
+                            showitem else '')
                 line = "<{0}l{1}{2}>{3}".format(ltype, atts, start, itemtag)
             else:
                 line = ("\t<{0}{1}>{2}".format(litem, atts, content) if
@@ -459,7 +464,7 @@ class Textile(object):
             else:
                 # if we're inside an extended block, add the text from the
                 # previous extension to the front
-                if ext:
+                if ext and out:
                     line = '{0}\n\n{1}'.format(out.pop(), line)
                 whitespace = ' \t\n\r\f\v'
                 if ext or not line[0] in whitespace:
@@ -488,7 +493,7 @@ class Textile(object):
                 cite = ''
                 graf = ''
 
-        if ext:
+        if ext and out:
             out.append(generate_tag(block.outer_tag, out.pop(),
                 block.outer_atts))
         return '\n\n'.join(out)
@@ -666,7 +671,10 @@ class Textile(object):
                             balanced = balanced - 1
                         if re.search(r'\S$', possibility, flags=re.U): # pragma: no branch
                             balanced = balanced + 1
-                        possibility = possible_start_quotes.pop()
+                        try:
+                            possibility = possible_start_quotes.pop()
+                        except IndexError:
+                            break
                     else:
                         # If quotes occur next to each other, we get zero
                         # length strings.  eg. ...""Open the door,
@@ -750,9 +758,9 @@ class Textile(object):
             $'''.format(cls_re_s, regex_snippets['space']), inner,
                 flags=re.X | re.U)
 
-        atts = m.group('atts') or ''
-        text = m.group('text') or '' or inner
-        title = m.group('title') or ''
+        atts = (m and m.group('atts')) or ''
+        text = (m and m.group('text')) or inner
+        title = (m and m.group('title')) or ''
 
         pop, tight = '', ''
         counts = { '[': None, ']': url.count(']'), '(': None, ')': None }
@@ -811,7 +819,7 @@ class Textile(object):
             """If we find a closing square bracket we are going to see if it is
             balanced.  If it is balanced with matching opening bracket then it
             is part of the URL else we spit it back out of the URL."""
-            # If counts['['] is None, count the occurrences of '[' 
+            # If counts['['] is None, count the occurrences of '['
             counts['['] = counts['['] or url.count('[')
 
             if counts['['] == counts[']']:
@@ -1010,7 +1018,7 @@ class Textile(object):
             \!                  # opening !
             (\<|\=|\>)?         # optional alignment atts
             ({0})               # optional style,class atts
-            (?:\. )?            # optional dot-space
+            (?:\.\s)?           # optional dot-space
             ([^\s(!]+)          # presume this is the src
             \s?                 # optional space
             (?:\(([^\)]+)\))?   # optional title
